@@ -65,11 +65,16 @@ namespace Hyprtoolkit {
         virtual void setMouseButton(std::function<void(Input::eMouseButton, bool)>&& fn);
         virtual void setMouseAxis(std::function<void(Input::eAxisAxis, float)>&& fn);
 
+        virtual void setTooltip(std::string&&);
+
         virtual void setRepositioned(std::function<void()>&& fn);
 
         virtual void setGrow(bool grow);
         virtual void setGrow(bool growH, bool growV);
 
+        // forces a reposition right now, useful for pre-calculating expected sizes
+        virtual void forceReposition();
+
         HT_HIDDEN :
 
             /* Sizes for auto positioning in layouts */
